mim
===

.. currentmodule:: bcselector.information_theory.j_criterion_approximations

.. autofunction:: mim

mifs
====

.. currentmodule:: bcselector.information_theory.j_criterion_approximations

.. autofunction:: mifs

mrmr
====

.. currentmodule:: bcselector.information_theory.j_criterion_approximations

.. autofunction:: mrmr

jmi
===

.. currentmodule:: bcselector.information_theory.j_criterion_approximations

.. autofunction:: jmi

cife
====

.. currentmodule:: bcselector.information_theory.j_criterion_approximations

.. autofunction:: cife